==> cscec5bhn-wzxt-api-3.0.1-20221126.102326-141-sources.jar: com/ejianc/business/wzxt/vo/CountVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 智能点数
 * 
 * @author generator
 * 
 */
public class CountVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String imageUrl;      // 原图片链接
    private String countImageUrl; // 点数图片链接
    private String detectPoint;   // 自动识别点坐标
    private String annotatePoint; // 人工标记点坐标
    private Integer detectNum;    // 自动识别数量
    private Integer annotateNum;  // 人工标记数量
    private Integer countNum;     // 智能点数总数量  （自动识别+人工标记）

    private Float width;
    private String materialType; // 材料类型
    private Float totalLength;   // 物料总长度（自动计算）
    private Float length;        // 单根物料长度
    private String note;         // 备注

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date uploadTime;    // 上传时间
    private String deviceId;    // 点数设备型号
    private String state;        // 推送状态
    private String detailid;     // 点数物资Id
    private String materialName; // 物资名称
    private String materialCode; // 物资编码
    private String spec;          // 物资型号
    private String billCode;      // 轻量化单据编号

    private String parentOrgId;       // 所属公司Id
    private String orgId;             // 项目部Id
    private String orgName;           // 项目部名称
    private String supplierName;      // 供应商名称
    private String supplierId;        // 供应商Id
    private String contractName;      // 合同名称
    private String contractId;        // 合同Id

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }
    public String getCountImageUrl() {
        return countImageUrl;
    }

    public void setCountImageUrl(String countImageUrl) {
        this.countImageUrl = countImageUrl;
    }
    public String getDetectPoint() {
        return detectPoint;
    }

    public void setDetectPoint(String detectPoint) {
        this.detectPoint = detectPoint;
    }
    public String getAnnotatePoint() {
        return annotatePoint;
    }

    public Integer getDetectNum() {
        return detectNum;
    }

    public void setDetectNum(Integer detectNum) {
        this.detectNum = detectNum;
    }

    public Integer getAnnotateNum() {
        return annotateNum;
    }

    public void setAnnotateNum(Integer annotateNum) {
        this.annotateNum = annotateNum;
    }

    public Integer getCountNum() {
        return countNum;
    }

    public void setCountNum(Integer countNum) {
        this.countNum = countNum;
    }

    public void setAnnotatePoint(String annotatePoint) {
        this.annotatePoint = annotatePoint;
    }
    public Float getWidth() {
        return width;
    }

    public void setWidth(Float width) {
        this.width = width;
    }
    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }
    public Float getTotalLength() {
        return totalLength;
    }

    public void setTotalLength(Float totalLength) {
        this.totalLength = totalLength;
    }
    public Float getLength() {
        return length;
    }

    public void setLength(Float length) {
        this.length = length;
    }
    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }
    public Date getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Date uploadTime) {
        this.uploadTime = uploadTime;
    }
    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }
    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }
    public String getDetailid() {
        return detailid;
    }

    public void setDetailid(String detailid) {
        this.detailid = detailid;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(String parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
}

==> cscec5bhn-wzxt-api-3.0.1-20230316.075751-156-sources.jar: com/ejianc/business/wzxt/vo/CountVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 智能点数
 * 
 * @author generator
 * 
 */
public class CountVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long realCorpId;         // 项目所属公司Id
    private String realCorpName;     // 项目所属公司名称
    private Long projectId;          // 项目Id
    private String projectName;      // 项目名称

    private String imageUrl;      // 原图片链接
    private String countImageUrl; // 点数图片链接
    private String detectPoint;   // 自动识别点坐标
    private String annotatePoint; // 人工标记点坐标
    private Integer detectNum;    // 自动识别数量
    private Integer annotateNum;  // 人工标记数量
    private Integer countNum;     // 智能点数总数量  （自动识别+人工标记）

    private Float width;
    private String materialType; // 材料类型
    private Float totalLength;   // 物料总长度（自动计算）
    private Float length;        // 单根物料长度
    private String note;         // 备注

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date uploadTime;    // 上传时间
    private String deviceId;    // 点数设备型号
    private String state;        // 推送状态
    private String detailid;     // 点数物资Id
    private String materialName; // 物资名称
    private String materialCode; // 物资编码
    private String spec;          // 物资型号
    private String billCode;      // 轻量化单据编号

    private String parentOrgId;       // 所属公司Id
    private String orgId;             // 项目部Id
    private String orgName;           // 项目部名称
    private String supplierName;      // 供应商名称
    private String supplierId;        // 供应商Id
    private String contractName;      // 合同名称
    private String contractId;        // 合同Id

    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }

    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }
    public String getCountImageUrl() {
        return countImageUrl;
    }

    public void setCountImageUrl(String countImageUrl) {
        this.countImageUrl = countImageUrl;
    }
    public String getDetectPoint() {
        return detectPoint;
    }

    public void setDetectPoint(String detectPoint) {
        this.detectPoint = detectPoint;
    }
    public String getAnnotatePoint() {
        return annotatePoint;
    }

    public Integer getDetectNum() {
        return detectNum;
    }

    public void setDetectNum(Integer detectNum) {
        this.detectNum = detectNum;
    }

    public Integer getAnnotateNum() {
        return annotateNum;
    }

    public void setAnnotateNum(Integer annotateNum) {
        this.annotateNum = annotateNum;
    }

    public Integer getCountNum() {
        return countNum;
    }

    public void setCountNum(Integer countNum) {
        this.countNum = countNum;
    }

    public void setAnnotatePoint(String annotatePoint) {
        this.annotatePoint = annotatePoint;
    }
    public Float getWidth() {
        return width;
    }

    public void setWidth(Float width) {
        this.width = width;
    }
    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }
    public Float getTotalLength() {
        return totalLength;
    }

    public void setTotalLength(Float totalLength) {
        this.totalLength = totalLength;
    }
    public Float getLength() {
        return length;
    }

    public void setLength(Float length) {
        this.length = length;
    }
    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }
    public Date getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Date uploadTime) {
        this.uploadTime = uploadTime;
    }
    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }
    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }
    public String getDetailid() {
        return detailid;
    }

    public void setDetailid(String detailid) {
        this.detailid = detailid;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(String parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
}
